REM INFO: FillFromFile.csc v2.2 (PP12)
REM Copyright  James Aswell, 2002
REM 
REM DESCRIPTION:
REM This script simply fills the current image or object with a
REM file passed as a command line parameter or a file selected
REM through a file dialog.  If this script is compiled as an EXE
REM then set as an Action for file types such as BMP within
REM Explorer, it offers the ability to use Photo-Paint Scrapbook
REM feature for applying bitmap fills.


WITHOBJECT "CorelPhotoPaint.Automation.12"
	ON ERROR GOTO ERRORHANDLER

	IF .GetDocumentCount() = 0 THEN
		MESSAGE "An open document is required to perform this action."

	ELSE
		'Get image path from the commandline or from a file box
		FillFile$=GETCOMMANDLINE()
		IF FillFile$ = "" Then
			'SETCURRFOLDER "C:\My Pictures\" 'set the default folder
			FillFile$=GETFILEBOX("Image Files|*.GIF;*.JPG;*.BMP;*.CPT;*.TIF;*.PCX|All Files|*.*", "Choose an image...", 0,"")
		ENDIF

		'If quotes are around file name, strip them
		IF INSTR(FillFile$, CHR(34)) THEN
			FillFile$ = LEFT(FillFile$, LEN(FillFile$) - 1)
			FillFile$ = RIGHT(FillFile$, LEN(FillFile$) - 1)
		ENDIF
	
		IF FillFile$ <> "" THEN
	
			ObjCount& = .GetObjectCount()
	
			'Find any objects that are selected
			IF ObjCount& > 0 THEN 

				ObjSelect& = 0
	
				FOR i& = 1 TO ObjCount&
					IF .GetObjectIsSelected(i&) <> 0 THEN 
						ObjSelect& = i&
					ENDIF
				NEXT i				

				IF ObjSelect& <> 0 THEN
					.GetObjectRectangle ObjSelect&, bl&, bt&, br&, bb&
				ENDIF

			ENDIF

			'if a mask is present, save
			IF .GetMaskPresent() = 1 Then
		
				'check for existing mask temp file, define new temp file name
				mtpath$ = GETTEMPFOLDER()
				mtfile$ = "~masktemp"
				mtext$ = ".cpt"
				mtnumb& = -1

				Do
					mtnumb& = mtnumb& + 1
					MaskFile$ = GETTEMPFOLDER() & mtfile$ & mtnumb& & mtext$
				Loop While FileSize(MaskFile$) > 0 AND mtnumb& < 20

				'get the mask rectangle
				.MaskSave MaskFile$, 1808, 0
				.MaskRemove
				maskpresent = TRUE
			ELSE
				maskpresent = FALSE
			ENDIF

			.ObjectNew "Tile", 100, 0

			'fill the image
			.FillTool 0,0
				.ToleranceSettings 0, 100, 10, 10, 10
				.FillBitmap FillFile$, 32, 32, 0, 0, FALSE, 0, TRUE, FALSE, TRUE, 0, 0
				.Fill 0, 0, TRUE

			'select the original object
			.ObjectEdit ObjSelect&, FALSE

			.MaskCreate TRUE, 0
				.EndMaskCreate 

			'invert the mask
			.MaskInvert

			'select the new object
			.ObjectEdit ObjCount& + 1, FALSE
			
			'cut the mask
			.EditCutMask 5, 0, 0, 0, 0
			
			'remove the mask
			.MaskRemove
			
			IF maskpresent = TRUE THEN
				'restore saved mask
				.MaskLoad MaskFile$, 0, 0, 0, 0, 0
			
				'invert the mask
				.MaskInvert
			
				'cut the mask
				.EditCutMask 5, 0, 0, 0, 0
			
				'restore saved mask
				.MaskLoad MaskFile$, 0, 0, 0, 0, 0

				KILL MaskFile$
			ENDIF
			
			'select the original object
			.ObjectSelect ObjSelect&, True

			'combine new object with original selection
			.ObjectCombine
				.EndObject
			
		ENDIF
	ENDIF
END WITHOBJECT

stop

ERRORHANDLER:
SELECT CASE ERRNUM
	CASE 603
		RESUME NEXT
END SELECT

